package com.unis.qyzg.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.flowable.common.vo.ExamineVO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 *  企业资格管理  工作流
 * @ClassName: CompanyClient
 * @Description: COMPANY接口服务调用
 * @author xmpu
 * @date 2018年9月11日 下午7:53:37
 * 
 * @version v1.0
 */
@FeignClient(name = "qyzg-server")
@Component
public interface FlowableClient {


	/**
	 *  查询待办个人任务和组任务合并列表---不分页
	 *
	 *
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowAble/findByUserAndGroupTaskNoPage/{userId}/{areaCode}")
	ResponseWrapper findByUserAndGroupTaskNoPage(@PathVariable("userId") String  userId,@PathVariable("areaCode") String  areaCode);


	/**
	 * 待办任务-----查询办理任务明细  和审核信息
	 * @param taskId  任务ID
	 * @param procInsId 流程ID
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowAble/findByFormKeyByTaskId/{taskId}/{procInsId}")
	ResponseWrapper findByFormKeyByTaskId(@PathVariable("taskId") String  taskId,@PathVariable("procInsId") String  procInsId);


	/**
	 * 查询已办列表---不分页
	 * @param userId
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowAble/findByAlreadyDoneoPage/{userId}")
	ResponseWrapper findByAlreadyDoneoPage(@PathVariable("userId")String userId);




	/**
	 * 已办理任务-----查询办理任务明细  和审核信息
	 * @param taskId  任务ID
	 * @param procInsId 流程ID
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowAble/findByAlreadyDone/{taskId}/{procInsId}")
	ResponseWrapper findByAlreadyDone(@PathVariable("taskId") String  taskId,@PathVariable("procInsId") String  procInsId);




	/**
	 * 拾取任务，将组任务分给个人任务
	 * @param taskId  任务ID
	 * @param userId 用户ID
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowAble/claim/{taskId}/{userId}")
	ResponseWrapper claim(@PathVariable("taskId") String  taskId,@PathVariable("userId") String  userId);


	/**
	 * 工作流审批--通过，驳回,提交
	 * @param
	 * @return
	 */
	@RequestMapping(method = RequestMethod.POST, value = "/flowAble/startExamine")
	ResponseWrapper startExamine(@RequestBody ExamineVO examineVO);



	/**
	 * 生成流图 返回base64 编码
	 * @param processId  流程ID
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowAble/findByLcslImage/{processId}")
	ResponseWrapper findByLcslImage(@PathVariable("processId") String  processId);


	/**
	 * 获取流程审批历史
	 * @param processId   流程ID
	 * @return
	 */
	@RequestMapping(method = RequestMethod.GET, value = "/flowAble/findByProcessInfo/{processId}")
	ResponseWrapper findByProcessInfo(@PathVariable(value = "processId") String processId);


}
