package com.unis.qyzg.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.flowable.common.vo.FlowAbleCompleteVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.common.vo.UpdateSqztVO;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * 企业申请资格管理
 *
 * @author xmpu
 * @version v1.0
 * @ClassName: CompanyClient
 * @Description: COMPANY接口服务调用
 * @date 2018年9月11日 下午7:53:37
 */
@FeignClient(name = "qyzg-server")
@Component
public interface QyzgZgsqClient {

    /**
     * 根据统一社会信用代码判断企业是否可以新申请备案
     *
     * @param tyshxydm
     * @return
     */
    @GetMapping(value = "/qyzgZgsq/isNewApply/{tyshxydm}")
    ResponseWrapper isNewApply(@ApiParam(name = "tyshxydm", value = "统一社会信用代码")
                               @PathVariable(value = "tyshxydm") String tyshxydm);

    /**
     * 代办事项修改
     *
     * @param qyzgZgsqVO
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/qyzgZgsq/updateZgsq")
    ResponseWrapper updateZgsq(@RequestBody QyzgZgsqVO qyzgZgsqVO);

    /**
     * 申请统计
     *
     * @param zgsq
     * @param page
     * @param size
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/qyzgZgsq/findByPage/{page}/{size}")
    ResponseWrapper findByPage(@RequestBody QyzgZgsqVO zgsq, @PathVariable("page") Integer page, @PathVariable("size") Integer size);

    /**
     * 删除申请企业信息
     *
     * @param ids
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/qyzgZgsq/deletes")
    ResponseWrapper deletes(@RequestBody String[] ids);

    /**
     * 更新企业申请信息
     *
     * @param qyzgZgsqVO
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/qyzgZgsq/updateQyzgZgsq")
    ResponseWrapper updateQyzgZgsq(@RequestBody QyzgZgsqVO qyzgZgsqVO);


    /**
     * 根据areaCode获取企业申请资格
     *
     * @param areaCode
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/qyzgZgsq/selectQyzgAreaCode/{areaCode}")
    ResponseWrapper selectQyzgAreaCode(@PathVariable("areaCode") String areaCode);

    /**
     * 查询详情----资格申请
     *
     * @param id
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/qyzgZgsq/findById/{id}")
    ResponseWrapper findById(@PathVariable("id") String id);


    /**
     * 查询详情----资格申请
     *
     * @param lcslId
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/qyzgZgsq/findByLcslId/{lcslId}")
    ResponseWrapper findByLcslId(@PathVariable("lcslId") String lcslId);


    /**
     * 保存----资格申请
     *
     * @param qyzgZgsqVO
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/qyzgZgsq/save")
    ResponseWrapper save(@RequestBody QyzgZgsqVO qyzgZgsqVO);


    /**
     * 修改申请状态----资格申请
     *
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/qyzgZgsq/updateSqzt")
    ResponseWrapper updateSqzt(@RequestBody UpdateSqztVO updateSqztVO);


    @PostMapping("/qyzgZgsq/complete")
    ResponseWrapper complete(@RequestBody FlowAbleCompleteVO completeVO, @RequestParam("taskName") String taskName, @RequestParam("fjid") String fjid, @RequestParam("taskId") String taskId);


    /**
     * 功能描述: 备案填写---删除
     *
     * @Param: [id]
     * @Return: com.unis.common.utils.ResponseWrapper
     * @Author: zoujieli
     * @Date: 2020-02-28 16:16
     */
    @ApiOperation(value = "根据备案申请ID删除备案信息")
    @PutMapping(value = "/qyzgZgsq/delete")
    ResponseWrapper deleteRecordCertificate(@RequestParam("id") String id);
}
