package com.unis.qyzg.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.qyzg.common.vo.QyzgBazsVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

@FeignClient(name = "qyzg-server")
@Component
public interface RecordCertificateClient {

    /**
     * 备案证书管理---根据条件分页查询备案单位
     */
    @ApiOperation(value = "根据条件分页查询备案单位")
    @PostMapping(value = "/recordCertificate/pageList/{pageNum}/{pageSize}")
    ResponseWrapper selectRecordCompany(@RequestBody QyzgZgsqVO qyzgZgsqVO,
                                        @PathVariable("pageNum") Integer pageNum,
                                        @PathVariable("pageSize") Integer pageSize);

    /**
     * 备案证书管理---新增/更新备案证书
     */
    @ApiOperation(value = "新增/更新备案证书")
    @PostMapping(value = "/recordCertificate/recordCompany")
    ResponseWrapper recordCompany(@RequestBody QyzgBazsVO qyzgBazsVO);

    /**
     * 备案证书管理---根据证书ID查询备案证书详情
     */
    @ApiOperation(value = "根据证书ID查询备案证书详情")
    @GetMapping(value = "/recordCertificate/certificateDetail/{id}")
    ResponseWrapper certificateDetail(@PathVariable("id") String id,
                                      @RequestParam("dwdm") String dwdm);

    /**
     * 功能描述: 备案证书---列表
     *
     * @Param: [qyzgBazsVO]
     * @Return: com.unis.common.utils.ResponseWrapper
     * @Author: zoujieli
     * @Date: 2020-02-28 14:32
     */
    @ApiOperation(value = "根据企业统一社会信用代码查询备案证书列表")
    @PostMapping(value = "/recordCertificate/certificatePageList/{pageNum}/{pageSize}")
    ResponseWrapper findCertificatePageList(@RequestBody QyzgBazsVO qyzgBazsVO,
                                            @PathVariable(name = "pageNum") int pageNum,
                                            @PathVariable(name = "pageSize") int pageSize);
}
