package com.unis.qyzg.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.flowable.common.vo.DeploymentVO;
import com.unis.flowable.common.vo.ExamineVO;
import com.unis.flowable.common.vo.FlowAbleCompleteVO;
import com.unis.flowable.common.vo.FlowAbleStartVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.entity.father.QyzgZgsq;
import com.unis.qyzg.service.FlowAbleService;
import com.unis.qyzg.service.QyzgZgsqService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/7/12 0012 13:51
 * @Description:
 */
@RestController
@RequestMapping("/flowAble")
@Slf4j
@Api(value = "工作流", tags = "工作流")
public class FlowAbleController {

    @Autowired
    private FlowAbleService flowAbleService;
    @Autowired
    private QyzgZgsqService zgsqService;


    /**
     * 启动工作流
     * @param
     * @return
     */
    @ApiOperation(value = "启动工作流 ", notes = "参数：flowAbleStartVO ")
    @PostMapping(value = "/start")
    public ResponseWrapper start(
            @RequestBody FlowAbleStartVO flowAbleStartVO
    ) {
        String title="启动工作流";
        try {
            FlowAbleCompleteVO result=flowAbleService.start(flowAbleStartVO);
            if(result!=null){
                return ResponseWrapper.success(200, "查询成功", result);
            }else{
                return ResponseWrapper.error();
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


    /**
     * 查询待办个人任务和组任务合并列表---不分页
     * @param
     * @return
     */
    @ApiOperation(value = "查询待办个人任务和组任务合并列表---不分页", notes = "参数：completeVO ")
    @GetMapping(value = "/findByUserAndGroupTaskNoPage/{userId}/{areaCode}")
    public ResponseWrapper findByUserAndGroupTaskNoPage(
            @PathVariable("userId") String  userId,
            @PathVariable("areaCode") String  areaCode
    ) {
        String title="查询待办个人任务和组任务合并列表---不分页";
        try {
            List<DeploymentVO> result=flowAbleService.findByUserAndGroupTaskNoPage(userId, areaCode);
            return ResponseWrapper.success(200, "查询成功", result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


    /**
     * 查询办理任务明细  和审核信息
     * @param taskId
     * @return
     */
    @ApiOperation(value = "待办任务-----查询办理任务明细  和审核信息", notes = "参数：taskId 任务ID  procInsId 流程ID ")
    @GetMapping(value = "/findByFormKeyByTaskId/{taskId}/{procInsId}")
    public ResponseWrapper findByFormKeyByTaskId(
            @PathVariable("taskId") String taskId,
            @PathVariable("procInsId") String procInsId
    ) {
        try {
            Map map=flowAbleService.findByFormKeyByTaskId(taskId, procInsId);
            return ResponseWrapper.success(200, "查询成功", map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error();
        }
    }



    /**
     * 查询待办个人任务和组任务合并列表---不分页
     * @param
     * @return
     */
    @ApiOperation(value = "查询已办列表---不分页", notes = "参数：completeVO ")
    @GetMapping(value = "/findByAlreadyDoneoPage/{userId}")
    public ResponseWrapper findByAlreadyDoneoPage(
            @PathVariable("userId") String  userId
    ) {
        String title="查询待办个人任务和组任务合并列表---不分页";
        try {
            ResponseWrapper responseWrapper=flowAbleService.findByAlreadyDoneoPage(userId);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }




    /**
     * 查询已办理任务明细  和审核信息
     * @param taskId
     * @return
     */
    @ApiOperation(value = "已办理任务-----查询办理任务明细  和审核信息", notes = "参数：taskId 任务ID  procInsId 流程ID ")
    @GetMapping(value = "/findByAlreadyDone/{taskId}/{procInsId}")
    public ResponseWrapper findByAlreadyDone(
            @PathVariable("taskId") String taskId,
            @PathVariable("procInsId") String procInsId
    ) {
        try {
            Map map=flowAbleService.findByAlreadyDone(taskId, procInsId);
            return ResponseWrapper.success(200, "查询成功", map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error();
        }
    }






    /**
     * 工作流审批--通过，驳回,提交
     * @param
     * @return
     */
    @ApiOperation(value = "工作流审批--提交、通过，驳回,受理、不受理,不通过", notes = "参数：completeVO ")
    @PostMapping(value = "/startExamine")
    public ResponseWrapper startExamine(
            @RequestBody ExamineVO examineVO
    ) {
        String title="工作流审批--提交、通过，打回修改,受理、不受理,不通过,打回修改";
        try {
            QyzgZgsq zgsq = zgsqService.findByLcslId(examineVO.getProcInstId());
            ResponseWrapper responseWrapper=flowAbleService.startExamine(examineVO);
            if(responseWrapper.getInfoCode()==200){
                Map map= (Map) responseWrapper.getData();
                String result=map.get("result").toString();
                //流程结束更新表结构
                if("2".equals(result)){
                    QyzgZgsqVO qyzgZgsqVO = new QyzgZgsqVO();
                    if("通过".equals(examineVO.getStatus())){
                        //通过是更改申请资格状态
                        qyzgZgsqVO.setSqzt(2);
                        qyzgZgsqVO.setId(zgsq.getId());
                    }
                    if("不通过".equals(examineVO.getStatus()) || "不受理".equals(examineVO.getStatus())){
                        //3-审批完成（未通过）
                        qyzgZgsqVO.setSqzt(3);
                        qyzgZgsqVO.setId(zgsq.getId());
                    }
                    zgsqService.updateQyzgZgsq(qyzgZgsqVO);
                }else{
                    if("打回修改".equals(examineVO.getStatus())){
                        QyzgZgsqVO qyzgZgsqVO = new QyzgZgsqVO();
                        //3-审批完成（打回修改）
                        qyzgZgsqVO.setSqzt(5);
                        qyzgZgsqVO.setId(zgsq.getId());
                        zgsqService.updateQyzgZgsq(qyzgZgsqVO);
                    }
                }
            }
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


    @ApiOperation(value = "拾取任务，将组任务分给个人任务", notes = "参数：userId 用户  taskId 任务ID ")
    @GetMapping(value = "/claim/{taskId}/{userId}")
    public  ResponseWrapper claim(
            @PathVariable String taskId,
            @PathVariable String userId
    ) {
        try {
            ResponseWrapper responseWrapper= flowAbleService.claim(taskId, userId);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }



    @ApiOperation(value = "根据流程ID查询审核记录", notes = "参数：procInstId 流程ID ")
    @GetMapping(value = "/findByProcessInfo/{procInstId}")
    public  ResponseWrapper findByProcessInfo(
            @PathVariable String procInstId
    ) {
        try {
            List<Map> mapList= flowAbleService.findByProcessInfo(procInstId);
            return ResponseWrapper.success(200, "查询成功", mapList);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error();
        }
    }






    /**
     * 获取  下一个审核节点
     * @param
     * @return
     */
    @ApiOperation(value = "获取  下一个审核节点", notes = "参数：completeVO ")
    @PostMapping(value = "/getTaskAssignee")
    public ResponseWrapper getTaskAssignee(
            @RequestBody FlowAbleCompleteVO flowAbleCompleteVO
    ) {
        String title="获取  下一个审核节点";
        try {
            flowAbleService.getTaskAssignee(flowAbleCompleteVO);
            return ResponseWrapper.success(200, "查询成功", flowAbleCompleteVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    /**
     * 生成流图 返回base64 编码
     * @param processId  流程ID
     * @return
     */
    @ApiOperation(value = " 生成流图 返回base64 编码", notes = "参数：processId ")
    @GetMapping(value = "/findByLcslImage/{processId}")
    public  ResponseWrapper findByLcslImage(
            @PathVariable("processId") String processId
    ){
        ResponseWrapper responseWrapper=flowAbleService.findByLcslImage(processId);
        return responseWrapper;
    }


}