package com.unis.qyzg.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.qyzg.common.vo.QyzgQyzgxxVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.entity.father.QyzgQyzgxxDO;
import com.unis.qyzg.entity.father.QyzgZgsq;
import com.unis.qyzg.service.QyzgQyzgxxService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:38
 * @Description:
 */
@RestController
@Slf4j
@Api(value = "企业资格管理：企业资格信息", tags = "企业资格管理：企业资格信息")
@RequestMapping("/qyzgQyzgxx")
public class QyzgQyzgxxController {

    @Autowired
    private QyzgQyzgxxService zgService;

    @ApiOperation(value = "保存----资格信息", notes = "参数：已有资格 QyzgQyzgxxVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody QyzgQyzgxxVO zg
    ) {
        String title = "资格申请--保存";
        System.out.println("保存=====资格信息===" + zg.toString());
        try {
            boolean flag = zgService.save(zg);
            if (!flag) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error(title + "发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    @ApiOperation(value = "资格列表信息", notes = "参数：模糊搜索参数")
    @ApiImplicitParams({@ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)})
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody QyzgQyzgxxVO zg,
                                      @PathVariable Integer page, @PathVariable Integer size) {
        try {
            Map<String, Object> qyzgQyzgxxDOS = zgService.provinceFindByPage(zg, page, size);

            if (ObjectUtils.notEqual(qyzgQyzgxxDOS, null)) {
                return ResponseWrapper.success(200, "查询成功", qyzgQyzgxxDOS);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error("用户分页查询失败{}", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    /**
     * 查询企业资格详情
     * @param id
     * @return
     */
    @ApiOperation(value = "根据id查询详情", notes = "参数：资格id")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(@PathVariable("id") String id) {

        try {
            QyzgQyzgxxDO byid = zgService.findByid(id);
            if (ObjectUtils.equals(byid, null)) {
                return ResponseWrapper.error();
            }
            return ResponseWrapper.success(200, "查找成功", byid);
        } catch (Exception e) {
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


    /**
     * 撤销企业资格
     */
    @ApiOperation(value = "撤销企业资格信息", notes = "参数：资格id,撤销原因,撤销状态")
    @PostMapping(value = "/cancelQualification")
    public ResponseWrapper cancelQualification(@RequestBody QyzgQyzgxxVO zg) {
        try {
            boolean b = zgService.cancelQualification(zg);
            if (b) {
                return ResponseWrapper.success(200, "撤销成功", b);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error("撤销对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


}