package com.unis.qyzg.controller;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import com.unis.flowable.client.FlowAbleClient;
import com.unis.flowable.common.vo.FlowAbleCompleteVO;
import com.unis.flowable.common.vo.HistoryList;
import com.unis.qyzg.common.vo.HistoryVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.entity.father.QyzgZgsq;
import com.unis.qyzg.service.FlowAbleService;
import com.unis.qyzg.service.QyzgZgsqService;
import io.swagger.annotations.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.ibatis.javassist.expr.NewArray;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:38
 * @Description:
 */
@RestController
@Slf4j
@Api(value = "企业资格管理：资格申请", tags = "企业资格管理：资格申请")
@RequestMapping("/qyzgZgsq")
public class QyzgZgsqController {

    @Autowired
    private QyzgZgsqService qyzgZgsqService;
    @Autowired
    private FlowAbleService flowAbleService;
    @Autowired
    private FlowAbleClient flowAbleClient;

    @ApiOperation(value = "根据统一社会信用代码判断企业是否可以新申请备案", notes = "参数：统一社会信用代码")
    @GetMapping(value = "/isNewApply/{tyshxydm}")
    public ResponseWrapper isNewApply(@ApiParam(name = "tyshxydm", value = "统一社会信用代码")
                                      @PathVariable(value = "tyshxydm") String tyshxydm) {
        try {
            boolean isNewApply = qyzgZgsqService.isNewApply(tyshxydm);
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", isNewApply);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }


    @ApiOperation(value = "资格申请列表信息", notes = "参数：模糊搜索参数")
    @ApiImplicitParams({@ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)})
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(@RequestBody QyzgZgsqVO zgsq,
                                      @PathVariable Integer page, @PathVariable Integer size) {
        try {
            Map<String, Object> stringObjectMap = qyzgZgsqService.provinceFindByPage(zgsq, page, size);

            if (ObjectUtils.notEqual(stringObjectMap, null)) {
                return ResponseWrapper.success(200, "查询成功", stringObjectMap);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error("用户分页查询失败{}", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    /**
     * 更新草稿信息
     *
     * @param qyzgZgsqVO
     * @return
     */
    @ApiOperation(value = "更新草稿信信息", notes = "参数：qyzgZgsqVO")
    @PostMapping(value = "/updateQyzgZgsq")
    public ResponseWrapper updateQyzgZgsq(@RequestBody QyzgZgsqVO qyzgZgsqVO) {
        try {
            boolean flag = qyzgZgsqService.updateQyzgZgsq(qyzgZgsqVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            log.error("更新对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    /**
     * 代办事项修改
     *
     * @param qyzgZgsqVO
     * @return
     */
    @ApiOperation(value = "代办事项修改", notes = "参数：qyzgZgsqVO")
    @PostMapping(value = "/updateZgsq")
    public ResponseWrapper updateZgsq(@RequestBody QyzgZgsqVO qyzgZgsqVO) {
        try {
            boolean flag = qyzgZgsqService.updateZgsq(qyzgZgsqVO);
            if (flag) {
                return ResponseWrapper.success();
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("更新对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    /**
     * 保存----资格申请
     *
     * @param qyzgZgsqVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存----资格申请", notes = "参数：资格申请 qyzgZgsqVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(@RequestBody QyzgZgsqVO qyzgZgsqVO) {
        String title = "资格申请--保存";
        System.out.println("保存=====资格申请===" + qyzgZgsqVO.toString());
        try {
            String save = qyzgZgsqService.save(qyzgZgsqVO);
            if (save == null) {
                return ResponseWrapper.error("对象已存在无法添加");
            }
            return ResponseWrapper.success(200, "保存成功", save);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(title + "发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


    /**
     * 修改申请状态----资格申请
     *
     * @param qyzgZgsqVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "修改申请状态----资格申请", notes = "参数：资格申请 qyzgZgsqVO")
    @PostMapping(value = "/updateSqzt")
    public ResponseWrapper updateSqzt(
            @RequestBody QyzgZgsqVO qyzgZgsqVO
    ) {
        String title = "资格申请--保存";
        System.out.println("保存=====资格申请===" + qyzgZgsqVO.toString());
        try {
            QyzgZgsq qyzgZgsq = qyzgZgsqService.updateSqzt(qyzgZgsqVO);
            if (qyzgZgsq == null) {
                return ResponseWrapper.error("启动工作流失败!");
            }
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error(title + "发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    /**
     * 查询企业资格详情
     *
     * @param id
     * @return
     */
    @ApiOperation(value = "根据id查询详情", notes = "参数：资格id")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(@PathVariable("id") String id) {
        try {
            QyzgZgsq qyzg = qyzgZgsqService.findByid(id);
            if (ObjectUtils.equals(qyzg, null)) {
                return ResponseWrapper.error("500");
            }
            return ResponseWrapper.success(200, "查找成功", qyzg);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


    /**
     * 查询企业资格详情
     *
     * @param lcslId
     * @return
     */
    @ApiOperation(value = "根据流程ID查询详情", notes = "参数：资格id")
    @GetMapping(value = "/findByLcslId/{lcslId}")
    public ResponseWrapper findByLcslId(@PathVariable("lcslId") String lcslId) {
        try {
            QyzgZgsq qyzg = qyzgZgsqService.findByLcslId(lcslId);
            if (ObjectUtils.equals(qyzg, null)) {
                return ResponseWrapper.error("没有当前数据，请重新操作");
            }
            return ResponseWrapper.success(200, "查找成功", qyzg);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }


    /**
     * 根据areaCode获取该企业下的企业资格
     *
     * @param
     * @return
     */
    @ApiOperation(value = "根据areaCode获取该企业下的企业资格", notes = "参数：areaCode ")
    @GetMapping(value = "/selectQyzgAreaCode/{areaCode}")
    public ResponseWrapper selectQyzgAreaCode(@PathVariable("areaCode") String areaCode) {
        try {
            List<QyzgZgsq> lis = qyzgZgsqService.selectQyzgAreaCode(areaCode);
            return ResponseWrapper.success(200, "查询成功", lis);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error();
        }
    }

    @ApiOperation("审核")
    @PostMapping("/complete")
    public ResponseWrapper complete(@RequestBody FlowAbleCompleteVO completeVO, @RequestParam("taskName") String taskName, @RequestParam("fjid") String fjid, @RequestParam("taskId") String taskId) {
        SimpleDateFormat sf = new SimpleDateFormat("yyyy-MM-dd");
        String format = sf.format(new Date());
        ResponseWrapper complete = null;
        QyzgZgsq zgsq = qyzgZgsqService.findByLcslId(completeVO.getProcessId());
        QyzgZgsqVO qyzgsq = new QyzgZgsqVO();
        if (completeVO.getStatus().equals("2")) {
            qyzgsq.setId(zgsq.getId());
            qyzgsq.setSqzt(3);
            qyzgZgsqService.updateQyzgZgsq(qyzgsq);
        }
        //上级集团审核
        if (taskName.contains("上")) {
            if (completeVO.getStatus().equals("1")) {
                String status = flowAbleService.getStatus(CurrentUtil.getCreditCode());
                completeVO.setStatus(status);
            }
        }

        //拾取任务
        flowAbleService.claim(taskId, CurrentUtil.getUserId());
        HistoryVO historyVO = new HistoryVO(CurrentUtil.getUserName(), completeVO.getMessage(), format, format, taskName, CurrentUtil.getOrgName(), Integer.parseInt(completeVO.getStatus()));
        historyVO.setFjid(fjid);
        completeVO.setMessage(historyVO.toString());
        completeVO.setUserId(CurrentUtil.getUserId());
        ResponseWrapper responseWrapper = flowAbleService.complete(completeVO);
        if (responseWrapper.getInfoCode() == 200) {
            Map map = (Map) responseWrapper.getData();
            String result = map.get("result").toString();
            //流程结束更新表结构
            if ("2".equals(result)) {
                QyzgZgsqVO qyzgZgsqVO = new QyzgZgsqVO();
                if ("1".equals(completeVO.getStatus())) {
                    //通过是更改申请资格状态
                    qyzgZgsqVO.setSqzt(2);
                    qyzgZgsqVO.setId(zgsq.getId());
                    qyzgZgsqService.updateQyzgZgsq(qyzgZgsqVO);
                }
            }
        }
        return responseWrapper;
    }

    /**
     * 功能描述: 备案填写---删除
     *
     * @Param: [id]
     * @Return: com.unis.common.utils.ResponseWrapper
     * @Author: zoujieli
     * @Date: 2020-02-28 16:16
     */
    @ApiOperation(value = "根据备案申请ID删除备案信息")
    @PutMapping(value = "/delete")
    public ResponseWrapper deleteRecordCertificate(@RequestParam String id){
        try {
            qyzgZgsqService.deleteRecordCertificate(id);
            return ResponseWrapper.success(HttpStatus.OK.value(), "删除成功", null);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "删除失败", null);
        }
    }


}