package com.unis.qyzg.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.qyzg.common.vo.QyzgBazsVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.service.RecordCertificateService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * 备案证书管理
 */
@RestController
@RequestMapping(value = "/recordCertificate")
@Api(value = "备案证书管理", tags = "备案证书管理")
@Slf4j
public class RecordCertificateController {

    @Autowired
    private RecordCertificateService recordCertificateService;

    /**
     * 备案证书管理---根据条件分页查询备案单位
     */
    @ApiOperation(value = "根据条件分页查询备案单位")
    @PostMapping(value = "/pageList/{pageNum}/{pageSize}")
    public ResponseWrapper selectRecordCompany(@RequestBody QyzgZgsqVO qyzgZgsqVO,
                                               @PathVariable Integer pageNum,
                                               @PathVariable Integer pageSize) {
        try {
            Map resultMap = recordCertificateService.selectRecordCompany(qyzgZgsqVO, pageNum, pageSize);
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", resultMap);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }

    /**
     * 备案证书管理---新增/更新备案证书
     */
    @ApiOperation(value = "新增/更新备案证书")
    @PostMapping(value = "/recordCompany")
    public ResponseWrapper recordCompany(@RequestBody QyzgBazsVO qyzgBazsVO) {
        try {
            Integer i = recordCertificateService.recordCompany(qyzgBazsVO);
            return ResponseWrapper.success(HttpStatus.OK.value(), "新增/更新成功", null);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "新增/更新失败", null);
        }
    }

    /**
     * 备案证书管理---根据证书ID查询备案证书详情
     */
    @ApiOperation(value = "根据证书ID查询备案证书详情")
    @GetMapping(value = "/certificateDetail/{id}")
    public ResponseWrapper certificateDetail(@PathVariable(required = false) String id,
                                             @RequestParam(required = false) String dwdm){
        try {
            QyzgBazsVO qyzgBazsVO = recordCertificateService.certificateDetail(id, dwdm);
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", qyzgBazsVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }

    /**
     * 功能描述: 备案证书---列表
     *
     * @Param: [qyzgBazsVO]
     * @Return: com.unis.common.utils.ResponseWrapper
     * @Author: zoujieli
     * @Date: 2020-02-28 14:32
     */
    @ApiOperation(value = "根据企业统一社会信用代码查询备案证书列表")
    @PostMapping(value = "/certificatePageList/{pageNum}/{pageSize}")
    public ResponseWrapper findCertificatePageList(@RequestBody QyzgBazsVO qyzgBazsVO,
                                                   @PathVariable(name = "pageNum") int pageNum,
                                                   @PathVariable(name = "pageSize") int pageSize){
        try {
            if (qyzgBazsVO.getDwdm() == null){
                return ResponseWrapper.error(HttpStatus.BAD_REQUEST.value(), "单位代码（DWDM）不能为空", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", recordCertificateService.findCertificatePageList(qyzgBazsVO, pageNum, pageSize));
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), "查询失败", null);
        }
    }
}
