package com.unis.qyzg.domain;

import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.qyzg.common.vo.QyzgBazsVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.dao.QyzgZgsqMapper;
import com.unis.qyzg.dao.RecordCertificateMapper;
import com.unis.qyzg.entity.QyzgBazsDO;
import com.unis.qyzg.entity.father.QyzgZgsq;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * 备案证书管理
 */
@Component
public class RecordCertificateDomain {

    //申请状态3（审核通过）
    private final static String PASS_STATUS = "3";

    @Autowired
    private RecordCertificateMapper recordCertificateMapper;
    @Autowired
    private QyzgZgsqMapper qyzgZgsqMapper;

    public Map selectRecordCompany(QyzgZgsqVO qyzgZgsqVO, Integer pageNum, Integer pageSize) {
        QyzgZgsq qyzgZgsq = new QyzgZgsq();
        LsBeanUtils.copyAllProperties(qyzgZgsqVO, qyzgZgsq);
        //设置查询条件
        Example example = new Example(QyzgZgsq.class);
        Example.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(qyzgZgsq.getKzzd10())) {
            qyzgZgsq.getKzzd10().replaceAll("%", "-");
            criteria.andLike("kzzd10", "%" + qyzgZgsq.getKzzd10() + "%");
        }
        //申请状态:1.待提交 2.待审核 3.审核通过 4.驳回 5.备案已过期
        criteria.andIn("sqzt", Arrays.asList(3, 5));
        criteria.andEqualTo("status", 1);
        PageHelper.startPage(pageNum, pageSize);
        List<QyzgZgsq> qyzgZgsqs = qyzgZgsqMapper.selectByExample(example);

        //遍历qyzgZgsq，设置证书信息
        Example example1 = new Example(QyzgBazsDO.class);
        Example.Criteria criteria1 = null;

        if (qyzgZgsqs != null && qyzgZgsqs.size() > 0) {
            for (QyzgZgsq q : qyzgZgsqs) {
                example1.clear();
                criteria1 = example1.createCriteria();
                //criteria1.andEqualTo("stateCode", 1);//启用状态
                criteria1.andEqualTo("sqId", q.getId());
                QyzgBazsDO qyzgBazsDO = recordCertificateMapper.selectOneByExample(example1);
                //判断证书是否过期
                if (qyzgBazsDO != null) {
                    Date endTime = qyzgBazsDO.getYxsjjz();
                    if (endTime != null) {
                        if (endTime.compareTo(new Date()) == -1) {
                            //该证书已过期，更新证书状态和资格申请状态
                            qyzgBazsDO.setZszt(3);
                            recordCertificateMapper.updateByPrimaryKeySelective(qyzgBazsDO);
                            //申请状态设置为证书已过期
                            q.setSqzt(5);
                            qyzgZgsqMapper.updateByPrimaryKeySelective(q);
                        }
                    }
                    if (qyzgBazsDO != null) {
                        QyzgBazsVO qyzgBazsVO = new QyzgBazsVO();
                        LsBeanUtils.copyAllProperties(qyzgBazsDO, qyzgBazsVO);
                        q.setQyzgBazsVO(qyzgBazsVO);
                    }
                }
            }
        }
        PageInfo<QyzgZgsq> pageInfo = new PageInfo<>(qyzgZgsqs);

        List<QyzgZgsqVO> qyzgZgsqVOs = new ArrayList<>();
        LsBeanUtils.copyCollection(qyzgZgsqs, qyzgZgsqVOs, QyzgZgsqVO.class);
        HashMap<Object, Object> resultMap = new HashMap<>();
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("qyzgZgsqVOs", qyzgZgsqVOs);
        return resultMap;
    }

    /**
     * 备案证书管理---新增/更新备案证书
     */
    public Integer recordCompany(QyzgBazsVO qyzgBazsVO) {
        QyzgBazsDO qyzgBazsDO = new QyzgBazsDO();
        LsBeanUtils.copyAllProperties(qyzgBazsVO, qyzgBazsDO);

        Example example = new Example(QyzgBazsDO.class);
        Example.Criteria criteria = example.createCriteria();

        //判断表中是否已有该数据
        if (qyzgBazsDO.getId() == null) {
            //执行保存操作
            //根据统一社会信用代码查询SQZT=3（审核通过）的QYZG_ZGSQ表主键ID
            Example zgsqExample = new Example(QyzgZgsq.class);
            Example.Criteria zgsqCriteria = zgsqExample.createCriteria();
            zgsqCriteria.andEqualTo("qyId", qyzgBazsDO.getDwdm());
            zgsqCriteria.andEqualTo("sqzt", PASS_STATUS);
            QyzgZgsq qyzgZgsq = qyzgZgsqMapper.selectOneByExample(zgsqExample);
            qyzgBazsDO.setSqId(qyzgZgsq.getId());
            qyzgBazsDO.setId(UUIDUtils.uuid());
            return recordCertificateMapper.insertSelective(qyzgBazsDO);
        } else {
            //执行更新操作
            return recordCertificateMapper.updateByPrimaryKeySelective(qyzgBazsDO);
        }
    }

    /**
     * 备案证书管理---根据证书ID查询备案证书详情
     *
     * @param id
     * @return
     */
    public QyzgBazsVO certificateDetail(String id, String dwdm) {
        QyzgBazsDO qyzgBazsDO = null;
        if (id != null && !"0".equals(id)) {
            qyzgBazsDO = recordCertificateMapper.selectByPrimaryKey(id);
        } else if (dwdm != null) {
            Example example = new Example(QyzgBazsDO.class);
            Example.Criteria criteria = example.createCriteria();
            criteria.andEqualTo("stateCode", 1);
            criteria.andEqualTo("dwdm", dwdm);
            criteria.andNotIn("zszt", Arrays.asList(1));
            qyzgBazsDO = recordCertificateMapper.selectOneByExample(example);
        }

        QyzgBazsVO qyzgBazsVO = null;
        if (qyzgBazsDO != null) {
            qyzgBazsVO = new QyzgBazsVO();
            LsBeanUtils.copyAllProperties(qyzgBazsDO, qyzgBazsVO);
        }
        return qyzgBazsVO;
    }

    /**
     * 功能描述: 备案证书---查看
     *
     * @Param: [qyzgBazsVO]
     * @Return: com.unis.common.utils.ResponseWrapper
     * @Author: zoujieli
     * @Date: 2020-02-28 14:32
     */
    public Map findCertificatePageList(QyzgBazsVO qyzgBazsVO, int pageNum, int pageSize) {
        Example bazsExample = new Example(QyzgBazsDO.class);
        Example.Criteria bazsCriteria = bazsExample.createCriteria();
        bazsCriteria.andEqualTo("dwdm", qyzgBazsVO.getDwdm());
        bazsCriteria.andIn("zszt", Arrays.asList(2,3));
        //bazsCriteria.andEqualTo("stateCode", 1);
        PageHelper.startPage(pageNum, pageSize);
        List<QyzgBazsDO> qyzgBazsDOS = recordCertificateMapper.selectByExample(bazsExample);
        PageInfo<QyzgBazsDO> pageInfo = new PageInfo<>(qyzgBazsDOS);

        ArrayList<QyzgBazsVO> qyzgBazsVOS = null;
        if (qyzgBazsDOS != null && qyzgBazsDOS.size() > 0){
            qyzgBazsVOS = new ArrayList<>();
            LsBeanUtils.copyCollection(qyzgBazsDOS, qyzgBazsVOS, QyzgBazsVO.class);
        }

        HashMap<String, Object> resultMap = new HashMap<>();
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("qyzgBazsVOS", qyzgBazsVOS);

        return resultMap;
    }
}
