package com.unis.qyzg.service.impl;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.qyzg.common.vo.QyzgQyzgxxVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.dao.QyzgQyzgMapper;
import com.unis.qyzg.entity.father.QyzgQyzgxxDO;
import com.unis.qyzg.service.QyzgQyzgxxService;
import com.unis.qyzg.service.QyzgZgsqService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

/**
 * 企业资格管理：企业资格信息
 *
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:59
 * @Description:
 */
@Service
public class QyzgQyzgxxServiceImpl implements QyzgQyzgxxService {

    @Autowired
    private QyzgQyzgMapper QyzgQyzgMapper;

    @Autowired
    private QyzgZgsqService zgsqService;


    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, rollbackFor = Exception.class)
    public boolean save(QyzgQyzgxxVO qyzgQyzgxxVO) {
        QyzgQyzgxxDO qyzgQyzgxxDO = LsBeanUtils.copyProperties(qyzgQyzgxxVO, QyzgQyzgxxDO.class);
        QyzgQyzgMapper.insert(qyzgQyzgxxDO);
        return true;
    }


    /**
     * 资格列表
     *
     * @param zgVO
     * @param page
     * @param size
     * @return
     */
    @Override
    public Map<String, Object> provinceFindByPage(QyzgQyzgxxVO zgVO, Integer page, Integer size) {
        //获取所有有效的状态资格信息
        List<QyzgQyzgxxDO> lisZg = null;
        try {
            lisZg = QyzgQyzgMapper.selectAllZg(zgVO);
        } catch (Exception e) {
            e.printStackTrace();
        }
        //带有逾期数据集
        List<QyzgQyzgxxDO> lis = new ArrayList<>();
        for (QyzgQyzgxxDO zg : lisZg) {
            // 过期数据集
            if (null != zg.getYxqJzsj()) {
                // 过期时间
                Date endTime = zg.getYxqJzsj();
                // 获取系统当前时间
                Date nowDate = DateUtil.getNowDate();
                // 大于零的数据是过期的
                if (nowDate.getTime() - endTime.getTime() > 0) {
                    zg.setOverdue("已过期");
                    lis.add(zg);
                } else {
                    // 即将过期数据
                    Calendar calendar = Calendar.getInstance();
                    calendar.setTime(DateUtil.getNowDate());
                    // 当前时间加上一个月
                    calendar.add(Calendar.MONTH, 1);
                    Date time = calendar.getTime();
                    // 有效期小于当前日期加1 为即将过期
                    if (endTime.getTime() - time.getTime() < 0) {
                        zg.setOverdue("即将过期");
                        lis.add(zg);
                    } else {
                        lis.add(zg);
                    }
                }
            }
        }
        List<QyzgQyzgxxDO> resList = new ArrayList<>();
        // 从第几条数据开始
        int firstIndex = (page - 1) * size;
        // 到第几条数据结束
        int lastIndex = page * size;
        if (lis.size() >= lastIndex) {
            resList = lis.subList(firstIndex, lastIndex);
        } else {
            resList = lis.subList(firstIndex, lis.size());
        }
        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("total", lis.size());
        resultMap.put("resultList", resList);
        return resultMap;
    }


    /**
     * 查询资格详情
     *
     * @param id
     * @return
     */
    @Override
    public QyzgQyzgxxDO findByid(String id) {
        try {
            QyzgQyzgxxDO byId = QyzgQyzgMapper.findById(id);
            System.out.println(byId);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return QyzgQyzgMapper.findById(id);

    }


    /**
     * 撤销资格申请状态
     *
     * @param zg
     */
    @Override
    public boolean cancelQualification(QyzgQyzgxxVO zg) {
        QyzgQyzgxxDO qyzgQyzgxxDO = findByid(zg.getId());
        //申请对象
        QyzgZgsqVO vo = new QyzgZgsqVO();
        vo.setId(qyzgQyzgxxDO.getZgsqId());
        //撤销原因
        if (zg.getCxyy() != null) {
            vo.setCxyy(zg.getCxyy());
            //撤銷時間
            vo.setCxsj(new Date());
        }
        //撤销状态
        if (zg.getUndoState() !=null) {
            vo.setUndoState(zg.getUndoState());
        }
        //状态为4时 为已撤销
        vo.setSqzt(4);
        zgsqService.updateQyzgZgsq(vo);
//        deletes(id);
        qyzgQyzgxxDO.setSqzt(4);
        //修改资格信息状态
        QyzgQyzgMapper.updateByPrimaryKey(qyzgQyzgxxDO);
        return true;
    }


    /**
     * 删除企业资格
     */
    @Transactional(rollbackFor = Exception.class)
    public boolean deletes(String id) {
        QyzgQyzgMapper.deleteByPrimaryKey(id);
        return true;
    }


}



