package com.unis.qyzg.service.impl;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.*;
import com.unis.flowable.common.enums.FlowableEnum;
import com.unis.flowable.common.vo.FlowAbleCompleteVO;
import com.unis.flowable.common.vo.FlowAbleStartVO;
import com.unis.qyzg.client.DataDictClient;
import com.unis.qyzg.common.vo.QyzgBazsVO;
import com.unis.qyzg.common.vo.QyzgZgsqVO;
import com.unis.qyzg.dao.QyzgZgsqMapper;
import com.unis.qyzg.dao.RecordCertificateMapper;
import com.unis.qyzg.entity.QyzgBazsDO;
import com.unis.qyzg.entity.father.QyzgZgsq;
import com.unis.qyzg.service.FlowAbleService;
import com.unis.qyzg.service.QyzgQyzgxxService;
import com.unis.qyzg.service.QyzgZgsqService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Transactional;
import tk.mybatis.mapper.entity.Example;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.*;

/**
 * 企业资格管理：资格申请
 *
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:39
 * @Description:
 */
@Service
public class QyzgZgsqServiceImpl implements QyzgZgsqService {

    @Autowired
    private QyzgZgsqMapper qyzgZgsqMapper;
    @Autowired
    private FlowAbleService flowAbleService;
    @Autowired
    private RecordCertificateMapper recordCertificateMapper;

    /**
     * 根据流程实例id查询详情
     * @param lcslId
     * @return
     */
    @Override
    public QyzgZgsq findByLcslId(String lcslId) {
        return qyzgZgsqMapper.findByLcslId(lcslId);
    }

    /**
     * 待办事项修改接口
     * @param qyzgZgsqVO
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean updateZgsq(QyzgZgsqVO qyzgZgsqVO) {
        try {
            if ("5".equals(qyzgZgsqVO.getKzzd5())) {
                qyzgZgsqVO.setSqzt(1);
            }
            if (qyzgZgsqMapper.updateZgsq(qyzgZgsqVO) < 1) {
                return false;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return true;
    }

    @Override
    public boolean isNewApply(String tyshxydm) {
        Example example = new Example(QyzgZgsq.class);
        Example.Criteria criteria = example.createCriteria();
        //判断企业是否可以新申请
        //申请状态：1---带提交；2-待审批；3-审批通过；4-审批未通过； 5驳回 6-证书已过期
        criteria.andIn("sqzt", Arrays.asList(1, 2, 3));
        criteria.andEqualTo("qyId", tyshxydm);
        QyzgZgsq qyzgZgsq = qyzgZgsqMapper.selectOneByExample(example);
        if (qyzgZgsq == null) {
            return true;//可以新申请
        } else {
            return false;//不可以新申请
        }
    }

    @Override
    public void deleteRecordCertificate(String id) {
        QyzgZgsq qyzgZgsq = new QyzgZgsq();
        qyzgZgsq.setId(id);
        qyzgZgsq.setStatus(0);//禁用
        qyzgZgsqMapper.updateByPrimaryKeySelective(qyzgZgsq);
    }

    /**
     * 承储格申请统计
     */
    @Override
    public Map<String, Object> provinceFindByPage(QyzgZgsqVO zgsqVO, Integer pageNum, Integer pageSize) {
        //获取所有有效的资格申请信息
        List<QyzgZgsq> qyzgZgsqs = null;

        Example zgsqExample = new Example(QyzgZgsq.class);
        Example.Criteria zgsqCriteria = zgsqExample.createCriteria();
        if (StringUtils.isNotBlank(zgsqVO.getZglxDm())){
            zgsqCriteria.andEqualTo("zglxDm", zgsqVO.getZglxDm());
        }
        if (zgsqVO.getZgsqlx() != null){
            zgsqCriteria.andEqualTo("zgsqlx", zgsqVO.getZgsqlx());
        }
        if (zgsqVO.getSqzt() != null){
            zgsqCriteria.andEqualTo("sqzt", zgsqVO.getSqzt());
        }
        if (StringUtils.isNotBlank(zgsqVO.getQyName())){
            try {
                String decode = URLDecoder.decode(zgsqVO.getQyName().replace("%", "--"),"utf-8");
                zgsqCriteria.andLike("kzzd2", "%"+decode+"%");
            } catch (UnsupportedEncodingException e) {
                e.printStackTrace();
            }
        }

        //判断是企业端还是管理端页面
        if ("管理端".equals(zgsqVO.getKzzd3())){
            zgsqCriteria.andNotIn("sqzt", Arrays.asList(1));
        }

        zgsqCriteria.andEqualTo("status", 1);

        PageHelper.startPage(pageNum, pageSize);
        qyzgZgsqs = qyzgZgsqMapper.selectByExample(zgsqExample);
        PageInfo<QyzgZgsq> pageInfo = new PageInfo<>(qyzgZgsqs);

        Example example = new Example(QyzgBazsDO.class);
        Example.Criteria criteria = null;

        //判断企业证书是否过期，并修改企业申请状态
        if (qyzgZgsqs != null && qyzgZgsqs.size() > 0){
            for (QyzgZgsq q: qyzgZgsqs){
                criteria = example.createCriteria();
                criteria.andEqualTo("stateCode", 1);//启用状态
                criteria.andEqualTo("dwdm", q.getQyId());
                QyzgBazsDO qyzgBazsDO = recordCertificateMapper.selectOneByExample(example);
                //判断证书是否过期
                if (qyzgBazsDO != null) {
                    Date endTime = qyzgBazsDO.getYxsjjz();
                    if (endTime != null) {
                        if (endTime.compareTo(new Date()) == -1) {
                            //该证书已过期，更新证书状态和资格申请状态
                            qyzgBazsDO.setZszt(3);
                            recordCertificateMapper.updateByPrimaryKeySelective(qyzgBazsDO);
                            //申请状态设置为证书已过期
                            q.setSqzt(5);
                            qyzgZgsqMapper.updateByPrimaryKeySelective(q);
                        }
                    }
                    if (qyzgBazsDO != null) {
                        QyzgBazsVO qyzgBazsVO = new QyzgBazsVO();
                        LsBeanUtils.copyAllProperties(qyzgBazsDO, qyzgBazsVO);
                        q.setQyzgBazsVO(qyzgBazsVO);
                    }
                }
            }
        }

        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("total", pageInfo.getTotal());
        resultMap.put("resultList", qyzgZgsqs);
        return resultMap;
    }

    /**
     * 多选删除
     * @param ids
     * @return
     * @throws Exception
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean deletes(String[] ids) {
        for (String id : ids) {
            qyzgZgsqMapper.logicDelete(id);
        }
        return true;
    }

    /**
     * 更新草稿信息
     * @param qyzgZgsqVO
     * @return
     * @throws Exception
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean updateQyzgZgsq(QyzgZgsqVO qyzgZgsqVO) {
        // 根据主键id获取库里的数据
        QyzgZgsq qyzgZgsq = findByid(qyzgZgsqVO.getId());
        // 拷贝页面数据
        QyzgZgsq qyzgZgsqDO = new QyzgZgsq();
        LsBeanUtils.copyPropertiesIgnoreNull(qyzgZgsqVO, qyzgZgsqDO);
        // 数据放进DO里
        UpdateTool.copyNullProperties(qyzgZgsq, qyzgZgsqDO);
        //状态为撤销时
        try {
            if (qyzgZgsqMapper.updateByKeySelective(qyzgZgsqDO) < 1) {
                return false;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return true;
    }

    /**
     * 根据areaCode获取该企业下的企业资格
     *
     * @param areaCode
     * @return
     */
    @Override
    public List<QyzgZgsq> selectQyzgAreaCode(String areaCode) {
        List<QyzgZgsq> qyzg = qyzgZgsqMapper.selectQyzgAreaCode(areaCode);
        return qyzg;
    }


    /**
     * 查询资格详情
     *
     * @param id
     * @return
     */
    @Override
    public QyzgZgsq findByid(String id) {
        QyzgZgsq qyzgZgsq = null;

        Example example = new Example(QyzgZgsq.class);
        Example.Criteria criteria = example.createCriteria();
        criteria.andEqualTo("id", id);
        try {
            qyzgZgsq = qyzgZgsqMapper.selectOneByExample(example);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return qyzgZgsq;
    }

    /**
     * 保存----资格申请
     *
     * @param qyzgZgsqVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, rollbackFor = Exception.class)
    public String save(QyzgZgsqVO qyzgZgsqVO) {
        QyzgZgsq qyzgZgsqDO = LsBeanUtils.copyProperties(qyzgZgsqVO, QyzgZgsq.class);
        qyzgZgsqDO.setCreateDate(DateUtil.getNowDate());
        qyzgZgsqMapper.insert(qyzgZgsqDO);
        //将该企业之前发放的证书禁用
        Example example = new Example(QyzgBazsDO.class);
        Example.Criteria criteria = example.createCriteria();
        criteria.andEqualTo("dwdm", qyzgZgsqDO.getQyId());
        QyzgBazsDO qyzgBazsDO = new QyzgBazsDO();
        qyzgBazsDO.setStateCode(0);
        recordCertificateMapper.updateByExampleSelective(qyzgBazsDO, example);
        return qyzgZgsqDO.getId();
    }

    /**
     * 修改申请状态----资格申请
     *
     * @param updateSqztVO
     * @return
     */
    @Override
    @Transactional(isolation = Isolation.READ_COMMITTED, rollbackFor = Exception.class)
    public QyzgZgsq updateSqzt(QyzgZgsqVO updateSqztVO) {

        QyzgZgsq qyzgZgsq = qyzgZgsqMapper.selectByKey(updateSqztVO.getId());
        try {
            qyzgZgsq.setRefersher(updateSqztVO.getRefersher());
            qyzgZgsq.setRefersherCode(updateSqztVO.getRefersherCode());
            qyzgZgsq.setRefersherDate(updateSqztVO.getRefersherDate());
            qyzgZgsq.setSqzt(updateSqztVO.getSqzt());
            qyzgZgsq.setTjspsj(new Date());
            qyzgZgsq.setZglxDm(updateSqztVO.getZglxDm());
            //申请状态为1 表是为批中，并且启动功作流
            if (updateSqztVO.getSqzt().intValue() == 1) {
                //工作流调用参数
                FlowAbleStartVO flowAbleStartVO = getFlowAbleStartVO(updateSqztVO);
                flowAbleStartVO.setStatusKey(updateSqztVO.getStatusKey());
                flowAbleStartVO.setStatus(updateSqztVO.getFlowStatus());
                flowAbleStartVO.setUserType(updateSqztVO.getUserType());
                flowAbleStartVO.setBbq(updateSqztVO.getBbq());
                flowAbleStartVO.setUserId(updateSqztVO.getUserId());
                flowAbleStartVO.setCreditCode(updateSqztVO.getUserCreditCode());
                flowAbleStartVO.setAccount(updateSqztVO.getAccount());
                flowAbleStartVO.setOrgName(updateSqztVO.getOrgName());
                flowAbleStartVO.setAreaCode(updateSqztVO.getAreaCode());
                //流程key
                String processKey = FlowableEnum.getCodeValue(Integer.valueOf(qyzgZgsq.getZglxDm()));
                flowAbleStartVO.setProcessKey(processKey);
                FlowAbleCompleteVO flowAbleCompleteVO = flowAbleService.start(flowAbleStartVO);
                if (flowAbleCompleteVO == null) {
                    return null;
                } else {
                    qyzgZgsq.setLcslId(flowAbleCompleteVO.getProcessId());
                }
            }
        } catch (NumberFormatException e) {
            e.printStackTrace();
        }

        return qyzgZgsq;
    }

    /**
     * 封装启动工作流的参数
     *
     * @param updateSqztVO
     */
    private FlowAbleStartVO getFlowAbleStartVO(QyzgZgsqVO updateSqztVO) {
        Integer year = DateUtil.getYearString();
        FlowAbleStartVO flowAbleStartVO = new FlowAbleStartVO();
        //报表期
        flowAbleStartVO.setBbq(String.valueOf(year));
        //数据id
        flowAbleStartVO.setId(updateSqztVO.getId());
        //流程状态status
        flowAbleStartVO.setStatus("0");
        //标识流程状态传参key  标识流程状态传参key    status : 0: 启动流程当前用户默认传值 1 上集集团用户  2   县粮食局用户  3 市粮食局用户  4  省粮食局用户 :  comeout 1 通过 2 驳回
        flowAbleStartVO.setStatusKey("status");
        //用户ID
        flowAbleStartVO.setUserId(updateSqztVO.getUserCreditCode());
        //用户类型
        flowAbleStartVO.setUserType(updateSqztVO.getUserType());
        //机构名称
        flowAbleStartVO.setOrgName(updateSqztVO.getOrgName());
        //登录用户名
        flowAbleStartVO.setAccount(updateSqztVO.getAccount());
        //行政区划
        flowAbleStartVO.setAreaCode(updateSqztVO.getAreaCode());
        //统一社会信用户代码
        flowAbleStartVO.setCreditCode(updateSqztVO.getUserCreditCode());
        return flowAbleStartVO;
    }
}